<?php
/**
 * gbs-unique functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package gbs-unique
 */

if ( ! function_exists( 'gbs_unique_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function gbs_unique_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on gbs-unique, use a find and replace
	 * to change 'gbs-unique' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'gbs-unique', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'gbs-unique' ),
	) );
	
	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'gbs-unique_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
	
	add_editor_style( 'css/editor-style.css' );

}
endif;
add_action( 'after_setup_theme', 'gbs_unique_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function gbs_unique_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'gbs-unique_content_width', 640 );
}
add_action( 'after_setup_theme', 'gbs_unique_content_width', 0 );



/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function gbs_unique_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'gbs-unique' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'gbs-unique' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'gbs_unique_widgets_init' );


/*Enqueue fonts */

function gbs_unique_portfolio_add_google_fonts() {

wp_enqueue_style( 'gbs-unique-fonts', 'https://fonts.googleapis.com/css?family=Raleway|Aladin|Open+Sans', false ); 

}

add_action( 'wp_enqueue_scripts', 'gbs_unique_portfolio_add_google_fonts' );



/**
 * Enqueue scripts and styles.
 */
function gbs_unique_scripts() {
	wp_enqueue_style( 'bootstrap-css', get_template_directory_uri() . '/css/bootstrap.min.css' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() .  '/css/font-awesome.min.css' );
	wp_enqueue_style( 'gbs-unique-style', get_stylesheet_uri());
	wp_enqueue_script( 'bootstrap-js', get_template_directory_uri() . '/js/bootstrap.min.js', array(), '3.0.0', true );

    wp_enqueue_script( 'gbs-unique-navigation', get_template_directory_uri() . '/js/navigation.js',false, NULL, 'all' );
	wp_enqueue_style( 'gbs-unique-responsive', get_template_directory_uri() . '/css/responsive.css', array(), '20151215', true );
	

	wp_enqueue_script( 'gbs-unique-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'gbs_unique_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

	
function gbs_unique_custom_excerpt($limit) {
	global $post;
  $excerpt = explode(' ', get_the_excerpt(), $limit);
  if (count($excerpt)>=$limit) {
    array_pop($excerpt);
    $excerpt = implode(" ",$excerpt)."....[ <a href='".get_permalink($post->ID) ."'>Read more</a> ]";
  } else {
    $excerpt = implode(" ",$excerpt);
  }	
  $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
  return $excerpt;
}